pub struct Certification {
pub name: Option<String>,
pub issuer: Option<String>,
pub issued: Option<PartialDate>,
pub expiry: Option<PartialDate>,
pub credential_id: Option<String>,
pub url: Option<String>,
}Fields
name: Option<String>issuer: Option<String>issued: Option<PartialDate>expiry: Option<PartialDate>credential_id: Option<String>url: Option<String>Trait Implementations
Sourceimpl Debug for Certification
impl Debug for Certification
Sourceimpl<'de> Deserialize<'de> for Certification
impl<'de> Deserialize<'de> for Certification
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Certification
impl JsonSchema for Certification
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Certification
impl RefUnwindSafe for Certification
impl Send for Certification
impl Sync for Certification
impl Unpin for Certification
impl UnsafeUnpin for Certification
impl UnwindSafe for Certification